Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(71)

Unified Diff: third_party/WebKit/public/web/WebView.h

Issue 2738133002: Provide an overload to WebView::create that does not require a WebViewClient. (Closed)
Patch Set: Add a derived WebViewClient and use it when no client is passed. Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « third_party/WebKit/Source/web/tests/WebViewTest.cpp ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/WebKit/public/web/WebView.h
diff --git a/third_party/WebKit/public/web/WebView.h b/third_party/WebKit/public/web/WebView.h
index 92bdf0736773c4ba96a72dbbc33fd146b0f7b557..1b737291a8b6e789f08f44422d9c7587fe131d07 100644
--- a/third_party/WebKit/public/web/WebView.h
+++ b/third_party/WebKit/public/web/WebView.h
@@ -119,9 +119,15 @@ class WebView : protected WebWidget {
// Initialization ------------------------------------------------------
// Creates a WebView that is NOT yet initialized. You will need to
- // call setMainFrame to finish the initialization. It is valid
- // to pass a null client pointer. The WebPageVisibilityState defines the
- // initial visibility of the page.
+ // call setMainFrame to finish the initialization. Use this factory method
+ // if you do not want to specify a client for callback notifications. The
+ // WebPageVisibilityState defines the initial visibility of the page.
+ BLINK_EXPORT static WebView* create(WebPageVisibilityState);
+
+ // Creates a WebView that is NOT yet initialized. You will need to
+ // call setMainFrame to finish the initialization. A valid WebViewClient must
+ // be supplied. The WebPageVisibilityState defines the initial visibility of
+ // the page.
BLINK_EXPORT static WebView* create(WebViewClient*, WebPageVisibilityState);
// After creating a WebView, you should immediately call this method.
« no previous file with comments | « third_party/WebKit/Source/web/tests/WebViewTest.cpp ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698